%define cleanscript S01parentlock

Summary: Fixes afs lock problems for firefox, thunderbird, and seamonkey
Name: SL_firefox_parentlock_fix
Version: 1.0
Release: 5
Copyright: GPL
Group: SL
URL: https://www.scientificlinux.org/
BuildArch: noarch

%description
When a users home area is in AFS space, it is possible for 
firefox, thunderbird, and/or seamonkey to leave a lock file called
.parentlock when they are closed.  The user is then not able to 
restart their problem until that lock file is removed.
This puts in a startup script that cleans up that file.

%files

#---------------------------------------------------------#

%triggerin -- firefox
shopt -s nullglob

for line in /usr/lib{,64}/firefox-1.*/init.d
do
	if [ -d "$line" -a ! -e "$line/%{cleanscript}" ] ; then
		cat > "$line/%{cleanscript}" << EOF
#!/bin/sh
#
# removes .parentlock
#
APP_FOLDER="\$HOME/.mozilla/firefox"
find "\$APP_FOLDER" -noleaf -type d -maxdepth 1 -mindepth 1 | while read i; do
    if [ ! -L "\$i/lock" -a -e "\$i/.parentlock" ]; then
        rm -f "\$i/.parentlock"
    fi
done
EOF
		chmod 755 "$line/%{cleanscript}"
	fi
done
:

#---------------------------------------------------------#

%triggerin -- thunderbird
shopt -s nullglob

for line in /usr/lib{,64}/thunderbird-1.*/init.d
do
	if [ -d "$line" -a ! -e "$line/%{cleanscript}" ] ; then
		cat > "$line/%{cleanscript}" << EOF
#!/bin/sh
#
# removes .parentlock
#
APP_FOLDER="\$HOME/.thunderbird"
find "\$APP_FOLDER" -noleaf -type d -maxdepth 1 -mindepth 1 | while read i; do
    if [ ! -L "\$i/lock" -a -e "\$i/.parentlock" ]; then
        rm -f "\$i/.parentlock"
    fi
done
EOF
		chmod 755 "$line/%{cleanscript}"
	fi
done
:

#---------------------------------------------------------#

%triggerin -- seamonkey
shopt -s nullglob

sed -i '/^[[:space:]]*exec[[:space:]]\+\$MOZ_PROGRAM/{i\
[ -x $MOZ_DIST_BIN/init.d/%{cleanscript} ] && $MOZ_DIST_BIN/init.d/%{cleanscript}
}' /usr/bin/mozilla

for line in /usr/lib{,64}/mozilla-seamonkey-1*/init.d
do
	if [ -d "$line" -a ! -e "$line/%{cleanscript}" ] ; then
		cat > "$line/%{cleanscript}" << EOF
#!/bin/sh
#
# removes .parentlock
#
APP_FOLDER="\$HOME/.mozilla"
find "\$APP_FOLDER" -noleaf -type d -maxdepth 2 -mindepth 2 | grep -v firefox | grep -v Cache | while read i; do
    if [ ! -L "\$i/lock" -a -e "\$i/.parentlock" ]; then
        rm -f "\$i/.parentlock"
    fi
done
EOF
		chmod 755 "$line/%{cleanscript}"
	fi
done
:

#---------------------------------------------------------#

%postun
#Let's clean ourselves up if we're the last
shopt -s nullglob

if [ "$1" = "0" ] ; then
	#First firefox
	for line in /usr/lib{,64}/firefox-1.*/init.d
	do
		if [ -e "$line/%{cleanscript}" ] ; then
			rm -f "$line/%{cleanscript}"
		fi
	done
	#Then thunderbird
	for line in /usr/lib{,64}/thunderbird-1.*/init.d
	do
		if [ -e "$line/%{cleanscript}" ] ; then
			rm -f "$line/%{cleanscript}"
		fi
	done
	#Finolly seamonkey
	for line in /usr/lib{,64}/mozilla-seamonkey-1*/init.d
	do
		if [ -e "$line/%{cleanscript}" ] ; then
			rm -f "$line/%{cleanscript}"
		fi
	done
	if [ -e /usr/bin/mozilla ] ; then
		sed -i '/%{cleanscript}/d' /usr/bin/mozilla
	fi
fi
:

%changelog
* Tue Sep 19 2006 Stephan Wiesand <stephan.wiesand@desy.de> 1.0-5
- make this work on 64bit platforms
- doublequote all shell variables

* Tue Sep 19 2006 Stephan Wiesand <stephan.wiesand@desy.de> 1.0-4
- Fixed a couple of tests
- Made the sed command for seamonkey a bit more readable
- Remove extra lines in /usr/bin/mozilla for seamonkey in postun
- Use the cleanscript macro everywhere

* Mon Sep 18 2006 Troy Dawson <dawson@fnal.gov> 1.0-2
- Fixed seamonkey's script

* Mon Sep 18 2006 Troy Dawson <dawson@fnal.gov> 1.0-2
- Fixed scripts by puting a \ infront of the $'s
- Added bit to seamonkey trigger script so that it works
- Added postun script so we clean up ourserves.

* Fri Sep 15 2006 Troy Dawson <dawson@fnal.gov> 1.0-1
- First go round of putting in the parentlock removers
